Argentina's Fighter Purchase May Threaten Britain - Business Insider
Author: David Cenciotti, The Aviationist
Description: Russia is supplying Argentina with Su-24s in exchange for food.
Date: 2014-12-29

- Featured
- Trending
- Recent

###

From
To
You have successfully emailed the post.
Military & Defense More: The Aviationist Argentina Britain Falkland Islands
Military Defense

# Argentina's Huge Fighter Jet Purchase Could Raise Tensions With Britain

- David Cenciotti, The Aviationist

- Dec. 29, 2014, 5:04 PM
- 5,263
- 5

- facebook
- linkedin
- twitter
- google+
- print
- email

- print
- email

- share
- share
- tweet
- share
- print
- email

- Share on Facebook
- Share on Twitter
- Share on Linkedin
- share
- print
- email

Shamil Zhumatov/REUTERSA Sukhoi Su-24 jet fighter drops flares during a joint Kazakh-Russian military exercise at Otar millitary range

The UK may be forced to review its Falkland Islands air defenses to face a renewed threat in the South Atlantic.

According to a report in the Daily Express newspaper, the Argentine Air Force is set to get a dozen Sukhoi Su-24 Fencer attack planes from Russia in return for foodstuff.

Due to this, the UK Ministry of Defense is in the process of reviewing the Falkland Islands air defenses. The delivery of the supersonic, all-weather attack aircraft could pose a threat to the islands, referred to as “Malvinas” by Argentina.

According to Jane’s, the islands current British air defenses include four Eurofighter Typhoon jets, Rapier SAM (Surface to Air Missile) systems, along with about 1,200 troops permanently stationed in the South Atlantic base.

Even though the Typhoons are modern enough to deal with a dozen Su-24s, the Soviet-era twin-engined two-seater are able to perform ultra-low level surface and maritime strike missions. The planes can be outfitted with a wide variety of General Purpose as well as Laser Guided Bombs and stand-off missiles, such as the Kh-31 (AS-17 “Krypton”) anti-radiation and anti-shipping sea-skimming missiles.

We don’t know whether the potential deal includes armament; still the possible delivery of Su-24s to Argentina makes the Falkland Islands a bit more vulnerable to an attack by the Fuerza Aérea Argentina.

This article originally appeared at The Aviationist. Copyright 2015. Follow The Aviationist on Twitter.

SEE ALSO: Russia is deploying a drone fleet to the Arctic

- facebook
- linkedin
- twitter
- google+
- email

- email

- share
- share
- tweet
- share
- email

- Share on Facebook
- Share on Twitter
- Share on Linkedin
- Share on Google Plus
- email

### Recommended For You

- ####

- ####

- ####

- ####

- ####

### Comments

Loading

# Argentina's Huge Fighter Jet Purchase Could Raise Tensions With Britain

Argentina's Huge Fighter Jet Purchase Could Raise Tensions With Britain

The UK may be forced to review its Falkland...

### Get Military & Defense Emails & Alerts

Learn More »

- Military Select

More
Featured

- Business Insider Select
- Tech Select
- Tech Chart Of The Day
- Markets Chart Of The Day
- 10 Things Before the Opening Bell
- Instant MBA
- Breaking News
- Business Insider Events

Entertainment

- Entertainment Select
- Sports Select

Finance

- Finance Select
- Markets Select
- Monday Scouting Report
- Your Money Select
- Financial Advisor Insights
- Smart Investor

Strategy

- Strategy Select
- Advertising Select
- Retail Select
- Careers Select
- Advertising: The Brief

Politics

- Politics Select
- Military Select
- Law & Order Select

Life

- Life Select
- Transportation Select
- Education Select

Tech

- Enterprise Select
- Science Select
- Mobile Chart Of The Day
- E-Commerce Chart Of The Day
- Payments Chart Of The Day
- Digital Media Chart Of The Day
- IoT Chart of the Day

Charts of the Day

- Sports Chart Of The Day

Top 10 Things

- 10 Things In Tech You Need To Know
- Closing Bell

##### Advertisement

### Your Money

NASDAQ Composite | 4,727 | -9.24 | (-0.195%)
S&P 500 | 2,058 | -0.7 | (-0.034%)
NYSE Composite | 10,831 | -8.32 | (-0.077%)

##### Sponsored By

### Featured

- Here's The Surprising Story Behind Spanx CEO Sara Blakely's 'Aha Moment'

  More "Idea Factory" »

- NBA POWER RANKINGS: Where Every Team Stands Going Into 2015

  More "2015 Watch List" »

- These 6 Charts Show How US Energy Boomed And Disrupted The Global Energy Game

  More "Think Global" »

- Peter Thiel Explains Why Mentorship Is Tricky For Tech Companies

  More "Idea Factory" »

### Welcome, !

##### You are logged into Facebook

##### Social:

- Your Activity|

  ### These articles have been shared on your timeline. You can remove them here:

- Options

  ### Notify me when a story is shared.

  Yes No

### Welcome, !

##### You are logged in with Google

##### Social:

- Your Activity|

  ### These articles have been added to your Google activity log. You can remove them here:

- Options

  ### Notify me when a story is shared.

  Yes No

### Trending

### BI Intelligence

Here's How The Internet Of Things Will Grow Across Home, Enterprise, And Government
Same-Day Delivery Services Are Going After Brick-And-Mortar Retailers’ Last Big Advantage
THE BEACONS FAQ: It's Time To Set The Story Straight
How Social Networks Are Driving More Sales And Influencing Online And Offline Purchases

### Read Business Insider On The Go

FREE App
Download

Available for iPhone, iPad, Android, BlackBerry and Windows

#####

### Find A Job

- Tech Jobs
- Media Jobs
- Finance Jobs

- C-Level Jobs
- Design Jobs
- Sales Jobs

### Thanks to our partners